==> luna-ml-0.1.9.tar.gz: luna-ml-0.1.9/README.md <==
<br /><br />
<p align="center">
  <img width="160px" src="https://luna-ml.github.io/luna/_images/luna_logo.png" />
  <br /><br />
  Luna ML
  <br />
  <a href=https://luna.staroid.com target=_blank>luna.staroid.com</a> |
  <a href="https://luna-ml.github.io/luna" target=_blank>docs</a>
</p>
<br />
<br />

# Luna ML: Get your ML models evaluated

![](https://github.com/luna-ml/luna/actions/workflows/test.yml/badge.svg?branch=main)
[![](https://img.shields.io/badge/license-Apache%202-brightgreen.svg)](https://github.com/luna-ml/luna/blob/main/LICENSE)
[![](https://img.shields.io/pypi/v/luna-ml.svg)](https://pypi.org/project/luna-ml)


Luna ML provides ML model evaluation environment and display evaluation results as well as leaderboard when models are submitted. It works with any ML frameworks you uses and any evaluation criteria you defines.

<a href="https://luna.staroid.com"><img src="https://luna-ml.github.io/luna/_images/luna-ml_screenshot.png?" width="500"></a>

Luna ML is designed with MLOps in mind. Defining projects, evaluation environment and submitting models are done via making Pull requests on the connected GitHub repository. It automates processes using Github action.

## Documentation

 - [Overview](https://luna-ml.github.io/luna/overview/index.html) - Why Luna ML, How it works, FAQ
 - [Quickstart](https://luna-ml.github.io/luna/quickstart/index.html) - Install, Setup project repo, submit models and get evaluated
 - [References](https://luna-ml.github.io/luna/references/index.html) - luna.yaml, model.yaml, project directory structure

## See also

| Project | Description |
| ------ | --------- |
| [luna-ml](https://github.com/luna-ml/luna-ml) | Luna ML Client - The current repository |
| [luna-action](https://github.com/luna-ml/luna-action) | Luna ML Github action to automate Pull request review and submit on merge |
| [luna-project-template](https://github.com/luna-ml/luna-project-template) | Template for creating new Github repository for Luna ML Projects |

## Getting involved

You're welcomed ❤️ to leave questions, feedback and ideas!

 - [Discord channel](https://discord.com/channels/829867188092796968/829867188092796973) - [Invite link](https://discord.gg/QvPkuNsSFK)
 - [Issues](https://github.com/luna-ml/luna-ml/issues) - Feel free to create any questions, discussions, bug report.
 - [Pull requests](https://github.com/luna-ml/luna-ml/pulls) - Contribute to Luna ML client

 See [CONTRIBUTING](https://github.com/luna-ml/luna/blob/main/CONTRIBUTING.rst) for code contribution.

==> luna-ml-0.2.5.tar.gz: luna-ml-0.2.5/README.md <==
<br /><br />
<p align="center">
  <img width="160px" src="https://luna-ml.github.io/luna/_images/luna_logo.png" />
  <br /><br />
  Luna ML
  <br />
  <a href=https://luna.staroid.com target=_blank>luna.staroid.com</a> |
  <a href="https://luna-ml.github.io/luna" target=_blank>docs</a>
</p>
<br />
<br />

# Luna ML: Get your ML models evaluated

![](https://github.com/luna-ml/luna-ml/actions/workflows/test.yml/badge.svg?branch=main)
[![](https://img.shields.io/badge/license-Apache%202-brightgreen.svg)](https://github.com/luna-ml/luna-ml/blob/main/LICENSE)
[![](https://img.shields.io/pypi/v/luna-ml.svg)](https://pypi.org/project/luna-ml)


Luna ML provides ML model evaluation environment and display evaluation results as well as leaderboard when models are submitted. It works with any ML frameworks you uses and any evaluation criteria you defines.

<a href="https://luna.staroid.com"><img src="https://luna-ml.github.io/luna/_images/luna-ml_screenshot.png?" width="500"></a>

Luna ML is designed with MLOps in mind. Defining projects, evaluation environment and submitting models are done via making Pull requests on the connected GitHub repository. It automates processes using Github action.

## Documentation

 - [Overview](https://luna-ml.github.io/luna/overview/index.html) - Why Luna ML, How it works, FAQ
 - [Quickstart](https://luna-ml.github.io/luna/quickstart/index.html) - Install, Setup project repo, submit models and get evaluated
 - [References](https://luna-ml.github.io/luna/references/index.html) - luna.yaml, model.yaml, project directory structure

## See also

| Project | Description |
| ------ | --------- |
| [luna-ml](https://github.com/luna-ml/luna-ml) | Luna ML Client - The current repository |
| [luna-action](https://github.com/luna-ml/luna-action) | Luna ML Github action to automate Pull request review and submit on merge |
| [luna-project-template](https://github.com/luna-ml/luna-project-template) | Template for creating new Github repository for Luna ML Projects |

## Getting involved

You're welcomed ❤️ to leave questions, feedback and ideas!

 - [Discord channel](https://discord.com/channels/829867188092796968/829867188092796973) - [Invite link](https://discord.gg/QvPkuNsSFK)
 - [Issues](https://github.com/luna-ml/luna-ml/issues) - Feel free to create any questions, discussions, bug report.
 - [Pull requests](https://github.com/luna-ml/luna-ml/pulls) - Contribute to Luna ML client

 See [CONTRIBUTING](https://github.com/luna-ml/luna-ml/blob/main/CONTRIBUTING.rst) for code contribution.
